@@ -1,15 +1,14 @@
-'''This is the bcfg2 tool for the Gentoo Portage system.'''
-__revision__ = '$Revision: 5526 $'
+"""This is the Bcfg2 tool for the Gentoo Portage system."""
+__revision__ = '$Revision$'
 
 import re
 import Bcfg2.Client.Tools
 
 class Portage(Bcfg2.Client.Tools.PkgTool):
-    '''The Gentoo toolset implements package and service operations and inherits
-    the rest from Toolset.Toolset'''
+    """The Gentoo toolset implements package and service operations and inherits
+    the rest from Toolset.Toolset."""
     name = 'Portage'
     __execs__ = ['/usr/bin/emerge', '/usr/bin/equery']
-    __important__ = ['/etc/make.conf']
     __handles__ = [('Package', 'ebuild')]
     __req__ = {'Package': ['name', 'version']}
     pkgtype = 'ebuild'
@@ -18,13 +17,16 @@ class Portage(Bcfg2.Client.Tools.PkgTool):
 
     def __init__(self, logger, cfg, setup):
         Bcfg2.Client.Tools.PkgTool.__init__(self, logger, cfg, setup)
+        self.__important__ = self.__important__ + ['/etc/make.conf']
         self.cfg = cfg
         self.installed = {}
         self.RefreshPackages()
 
     def RefreshPackages(self):
-        '''Refresh memory hashes of packages'''
-        cache = self.cmd.run("equery -q list")[1]
+        """Refresh memory hashes of packages."""
+        ret, cache = self.cmd.run("equery -q list")
+        if ret == 2:
+            cache = self.cmd.run("equery -q list '*'")[1]
         pattern = re.compile('(.*)-(\d.*)')
         self.installed = {}
         for pkg in cache:
@@ -36,7 +38,7 @@ class Portage(Bcfg2.Client.Tools.PkgTool):
                 self.logger.info("Failed to parse pkg name %s" % pkg)
 
     def VerifyPackage(self, entry, modlist):
-        '''Verify package for entry'''
+        """Verify package for entry."""
         if not 'version' in entry.attrib:
             self.logger.info("Cannot verify unversioned package %s" %
                (entry.attrib['name']))
@@ -59,7 +61,7 @@ class Portage(Bcfg2.Client.Tools.PkgTool):
         return False
 
     def RemovePackages(self, packages):
-        '''Deal with extra configuration detected'''
+        """Deal with extra configuration detected."""
         pkgnames = " ".join([pkg.get('name') for pkg in packages])
         if len(packages) > 0:
             self.logger.info('Removing packages:')
