@@ -350,7 +350,12 @@ class YUMng(Bcfg2.Client.Tools.PkgTool):
         for po in packages:
             d = {}
             for i in ['name', 'epoch', 'version', 'release', 'arch']:
-                d[i] = getattr(po, i)
+                if i == 'arch' and getattr(po, i) is None:
+                    d[i] = 'noarch'
+                elif i == 'epoch' and getattr(po, i) is None:
+                    d[i] = '0'
+                else:
+                    d[i] = getattr(po, i)
             self.installed.setdefault(po.name, []).append(d)
 
     def VerifyPackage(self, entry, modlist, pinned_version=None):
@@ -448,8 +453,16 @@ class YUMng(Bcfg2.Client.Tools.PkgTool):
                 self.logger.debug("  Not checking version for virtual package")
                 _POs = [ po for po in POs ]  # Make a copy
             elif entry.get('name') == 'gpg-pubkey':
-                _POs = [ p for p in POs if p.version == nevra['version'] \
-                         and p.release == nevra['release'] ]
+                if 'version' not in nevra:
+                    m = "Skipping verify: gpg-pubkey without an RPM version."
+                    self.logger.warning(m)
+                    continue
+                if 'release' not in nevra:
+                    m = "Skipping verify: gpg-pubkey without an RPM release."
+                    self.logger.warning(m)
+                    continue
+                _POs = [p for p in POs if p.version == nevra['version'] \
+                        and p.release == nevra['release']]
             else:
                 _POs = self.yb.rpmdb.searchNevra(**snevra)
             if len(_POs) == 0:
