@@ -13,12 +13,13 @@ class DecisionFile(Bcfg2.Server.Plugin.SpecificData):
 
 class DecisionSet(Bcfg2.Server.Plugin.EntrySet):
     def __init__(self, path, fam, encoding):
-        """Container for decision specification files
+        """Container for decision specification files.
 
         Arguments:
         - `path`: repository path
         - `fam`: reference to the file monitor
         - `encoding`: XML character encoding
+
         """
         pattern = '(white|black)list'
         Bcfg2.Server.Plugin.EntrySet.__init__(self, pattern, path, \
@@ -46,7 +47,7 @@ class Decisions(DecisionSet,
                 Bcfg2.Server.Plugin.Plugin,
                 Bcfg2.Server.Plugin.Decision):
     name = 'Decisions'
-    __version__ = '$Id: Decisions.py 5477 2009-10-07 14:46:08Z solj $'
+    __version__ = '$Id$'
     __author__ = 'bcfg-dev@mcs.anl.gov'
 
     def __init__(self, core, datastore):
@@ -55,6 +56,7 @@ class Decisions(DecisionSet,
         Arguments:
         - `core`: Bcfg2.Core instance
         - `datastore`: File repository location
+
         """
         Bcfg2.Server.Plugin.Plugin.__init__(self, core, datastore)
         Bcfg2.Server.Plugin.Decision.__init__(self)
