@@ -9,6 +9,7 @@ import os
 import os.path
 import socket
 import time
+import Bcfg2.Server.FileMonitor
 import Bcfg2.Server.Plugin
 
 class MetadataConsistencyError(Exception):
@@ -83,6 +84,8 @@ class Metadata(Bcfg2.Server.Plugin.Plugin,
             except:
                 print("Unable to add file monitor for groups.xml or clients.xml")
                 raise Bcfg2.Server.Plugin.PluginInitError
+   
+        self.pseudo_monitor = isinstance(core.fam, Bcfg2.Server.FileMonitor.Pseudo)
         self.states = {}
         if watch_clients:
             self.states = {"groups.xml":False, "clients.xml":False}
@@ -285,7 +288,7 @@ class Metadata(Bcfg2.Server.Plugin.Plugin,
                 continue
             else:
                 break
-        tree.write(client_tree)
+        tree.write(client_tree, pretty_print=True)
         fcntl.lockf(fd, fcntl.LOCK_UN)
         client_tree.close()
 
@@ -307,7 +310,7 @@ class Metadata(Bcfg2.Server.Plugin.Plugin,
                 continue
             else:
                 break
-        tree.write(client_tree)
+        tree.write(client_tree, pretty_print=True)
         fcntl.lockf(fd, fcntl.LOCK_UN)
         client_tree.close()
 
@@ -460,6 +463,13 @@ class Metadata(Bcfg2.Server.Plugin.Plugin,
         if profile not in self.public:
             self.logger.error("Failed to set client %s to private group %s" % (client, profile))
             raise MetadataConsistencyError
+        if self.pseudo_monitor:
+            # if we aren't using fam reload the clients.xml file in case its changed
+            try:
+                self.clientdata_original = lxml.etree.parse(self.data + "/clients.xml")
+            except Exception, e:
+                self.logger.error("Metadata: Failed to relad clients.xml. %s" % e)
+                raise MetadataConsistencyError
         if client in self.clients:
             self.logger.info("Changing %s group from %s to %s" % (client, self.clients[client], profile))
             cli = self.clientdata_original.xpath('.//Client[@name="%s"]' % (client))
@@ -490,14 +500,6 @@ class Metadata(Bcfg2.Server.Plugin.Plugin,
             raise MetadataRuntimeError
         # prep data
         dataroot = self.clientdata_original.getroot()
-        if hasattr(dataroot, 'iter'):
-            items = dataroot.iter()
-        else:
-            items = dataroot.getchildren()
-        for item in items:
-            # no items have text data of any sort
-            item.tail = None
-            item.text = None
         newcontents = lxml.etree.tostring(dataroot, pretty_print=True)
 
         fd = datafile.fileno()
@@ -735,6 +737,13 @@ class Metadata(Bcfg2.Server.Plugin.Plugin,
         client = meta.hostname
         if client in self.auth and self.auth[client] == 'bootstrap':
             self.logger.info("Asserting client %s auth mode to cert" % client)
+            if self.pseudo_monitor:
+                # if we aren't using fam reload the clients.xml file in case its changed
+                try:
+                    self.clientdata_original = lxml.etree.parse(self.data + "/clients.xml")
+                except Exception, e:
+                    self.logger.error("Metadata: Failed to relad clients.xml. %s" % e)
+                    raise MetadataConsistencyError
             cli = self.clientdata_original.xpath('.//Client[@name="%s"]' \
                                                  % (client))
             cli[0].set('auth', 'cert')
@@ -745,7 +754,7 @@ class Metadata(Bcfg2.Server.Plugin.Plugin,
         groups_tree = lxml.etree.parse(self.data + "/groups.xml")
         try:
             groups_tree.xinclude()
-        except lxml.etree.XincludeError:
+        except lxml.etree.XIncludeError:
             self.logger.error("Failed to process XInclude for file %s" % dest)
         groups = groups_tree.getroot()
         categories = {'default':'grey83'}
