@@ -20,8 +20,9 @@ define host{
 
 class NagiosGen(Bcfg2.Server.Plugin.Plugin,
                 Bcfg2.Server.Plugin.Generator):
-    '''NagiosGen is a Bcfg2 plugin that dynamically generates
-       Nagios configuration file based on Bcfg2 data.'''
+    """NagiosGen is a Bcfg2 plugin that dynamically generates
+       Nagios configuration file based on Bcfg2 data.
+    """
     name = 'NagiosGen'
     __version__ = '0.6'
     __author__ = 'bcfg-dev@mcs.anl.gov'
@@ -29,17 +30,23 @@ class NagiosGen(Bcfg2.Server.Plugin.Plugin,
     def __init__(self, core, datastore):
         Bcfg2.Server.Plugin.Plugin.__init__(self, core, datastore)
         Bcfg2.Server.Plugin.Generator.__init__(self)
-        self.Entries = {'ConfigFile':
+        self.Entries = {'Path':
                 {'/etc/nagiosgen.status'   : self.createhostconfig,
                 '/etc/nagios/nagiosgen.cfg': self.createserverconfig}}
 
-        self.client_attrib = {'encoding': 'ascii', 'owner':'root', \
-                         'group':'root', 'perms':'0400'}
-        self.server_attrib = {'encoding': 'ascii', 'owner':'nagios', \
-                         'group':'nagios', 'perms':'0440'}
+        self.client_attrib = {'encoding':'ascii',
+                              'owner':'root',
+                              'group':'root',
+                              'type':'file',
+                              'perms':'0400'}
+        self.server_attrib = {'encoding':'ascii',
+                              'owner':'nagios',
+                              'group':'nagios',
+                              'type':'file',
+                              'perms':'0440'}
 
     def createhostconfig(self, entry, metadata):
-        '''Build host specific configuration file'''
+        """Build host specific configuration file."""
         host_address = socket.gethostbyname(metadata.hostname)
         host_groups = [grp for grp in metadata.groups if \
                        os.path.isfile('%s/%s-group.cfg' % (self.data, grp))]
@@ -49,11 +56,16 @@ class NagiosGen(Bcfg2.Server.Plugin.Plugin,
         if host_groups:
             host_config += '        hostgroups      %s\n' % (",".join(host_groups))
 
-        if hasattr(metadata, 'Properties') and  \
-               'NagiosGen.xml' in metadata.Properties and \
-               metadata.Properties['NagiosGen.xml'].data.find(metadata.hostname) \
-               is not None:
-            directives = list(metadata.Properties['NagiosGen.xml'].data.find(metadata.hostname))
+        xtra = None
+        if hasattr(metadata, 'Properties') and \
+                'NagiosGen.xml' in metadata.Properties:
+            for q in (metadata.hostname, 'default'):
+                xtra = metadata.Properties['NagiosGen.xml'].data.find(q)
+                if xtra is not None:
+                    break
+
+        if xtra is not None:
+            directives = list(xtra)
             for item in directives:
                 host_config += '        %-32s %s\n' % (item.tag, item.text)
 
@@ -75,7 +87,7 @@ class NagiosGen(Bcfg2.Server.Plugin.Plugin,
             LOGGER.error(ioerr)
 
     def createserverconfig(self, entry, _):
-        '''Build monolithic server configuration file'''
+        """Build monolithic server configuration file."""
         host_configs  = glob.glob('%s/*-host.cfg' % self.data)
         group_configs = glob.glob('%s/*-group.cfg' % self.data)
         host_data = ""
